@@ -1,12 +1,14 @@
-#include "general.h"
+#include "aesopd.h"
 
 /* This function allocates a new Connection structure and initialises
    it to the ST_NOTUSED
  */
 void Connection_alloc(void) {
    
+#ifdef DEBUG
    if(debug)
       err_msg("Connection_alloc: allocating new structure, conn_size=%d", conn_size);
+#endif
 
    if(conn == NULL)
       conn = calloc(1, sizeof(Connection));
@@ -35,8 +37,10 @@ void Connection_alloc(void) {
 int Connection_add(int localfd) {
    int i;
 
+#ifdef DEBUG
    if(debug)
       err_msg("Connection_add: Adding Connection structure for fd=%d", localfd);
+#endif
 
    if(conn == NULL)
       Connection_alloc();
@@ -77,8 +81,10 @@ again:
 
 void Connection_del(Connection *con) {
 
+#ifdef DEBUG
    if(debug)
       err_msg("Connection_del: Deleting Connection structure for localfd=%d, remotefd=%d", con->localfd, con->remotefd);
+#endif
 
    if(con->localfd) {
       close(con->localfd);
@@ -127,8 +133,9 @@ void Connection_process(Connection *con) {
    int val = 1;
    long flags;
    conninit init;
-   struct sockaddr_in sin;
-   
+   struct sockaddr *sin;
+   socklen_t sinlen;   
+
    if(con->init.control & CNTRL_ENDPO) {	/* 2nd time visit as endpoint */
        FD_CLR(con->localfd, &rdset);
        init = con->init;
@@ -139,8 +146,12 @@ void Connection_process(Connection *con) {
       Readdata(con, FROM_LOCAL, max);
 
       if(con->lpos < sizeof(conninit)) {
+
+#ifdef DEBUG
          if(debug)
             err_msg("Connection_process: Read in %d bytes of conninit structure from localfd=%d", con->lpos - n, con->localfd);
+#endif
+
          FD_CLR(con->remotefd, &wrset);	/* Readdata() set con->remotefd on in wrset */
          return;
       }
@@ -148,15 +159,22 @@ void Connection_process(Connection *con) {
       FD_CLR(con->localfd, &rdset);
       FD_CLR(con->remotefd, &wrset);	/* Readdata() set con->remotefd on in wrset */
 
+#ifdef DEBUG
       if(debug)
          err_msg("Connection_process: Read in conninit structure, processing for localfd=%d", con->localfd);
+#endif
 
       memcpy(&init, con->lbuf, sizeof(conninit));
       memmove(con->lbuf, con->lbuf + sizeof(conninit), con->lpos - sizeof(conninit));
       con->lpos -= sizeof(conninit);
  
       if(ntohl(init.magic) != MAGIC) {
-         err_msg("Connection_process: init.magic = 0x%x", init.magic);
+
+#ifdef DEBUG
+	 if(debug)
+            err_msg("Connection_process: init.magic = 0x%x", init.magic);
+#endif
+
          Connection_del(con);
          return;
       }
@@ -164,14 +182,47 @@ void Connection_process(Connection *con) {
       con->init = init;
       con->init.control = ntohs(con->init.control);
 
+      if((!ipv6support) && (con->init.control & CNTRL_INET6)) {
+         err_msg("Connection_process: Got unsupported IPv6 request on fd=%d", con->localfd);
+         Connection_del(con);
+	 return;
+      }
+
       if(con->init.control & CNTRL_ENDPO) {	/* Endpoint */
          Connection_DH_init(con, AS_ENDPOINT);
          return;
       }
    }
 
-   if((sd = socket(AF_INET, SOCK_STREAM, 0)) == -1)
-      err_sys("Connection_process: socket error");
+   if((sin = w_setsockaddr(&init.targetip, init.targetport, &sinlen,
+                           con->init.control & CNTRL_INET6)) == NULL) {
+#ifdef DEBUG
+      if(debug)
+         err_msg("Connection_process: w_setsockaddr returned NULL\n");
+#endif
+
+      Connection_del(con);
+      return;
+   }
+
+#ifdef DEBUG
+   if(debug)
+      err_msg("Connection_process: Connection request for localfd=%d to %s", con->localfd, w_sock_ntop(sin));
+#endif
+
+   if((sd = socket(sin->sa_family, SOCK_STREAM, 0)) == -1) {
+      if(errno == EAFNOSUPPORT) {
+#ifdef DEBUG
+	 if(debug)
+            err_msg("Connection_process: No AF support for localfd=%d", con->localfd);
+#endif
+	 free(sin);
+   	 Connection_del(con);
+	 return;
+      } else {
+         err_sys("Connection_process: socket error");
+      }
+   }
 
    if((flags = fcntl(sd, F_GETFL, 0)) == -1)
       err_sys("Connection_process: fcntl F_GETFL error");
@@ -182,31 +233,28 @@ void Connection_process(Connection *con) {
    if(setsockopt(sd, SOL_SOCKET, SO_OOBINLINE, &val, sizeof(int)) == -1)
       err_sys("Connection_add: Can not set SO_OOBINLINE\n");
 
-   bzero(&sin, sizeof(sin));
-   sin.sin_family = AF_INET;
-   sin.sin_addr.s_addr = init.targetip;
-   sin.sin_port = init.targetport;
-
-   if(debug)
-      err_msg("Connection_process: Connection request for localfd=%d to %s:%hu", con->localfd,
-		inet_ntoa(sin.sin_addr), ntohs(sin.sin_port));
-
-   if((n = connect(sd, (struct sockaddr *)&sin, sizeof(sin))) == -1) {
+   if((n = connect(sd, sin, sinlen)) == -1) {
       if(errno != EINPROGRESS) {
          err_ret("Connection_process: connect didnt return EINPROGRESS");
+	 close(sd);
 	 Connection_del(con);
+	 free(sin);
          return;
       }
    } else if(n == 0) {	/* Connection succeeded */
       con->remotefd = sd;
       maxfd = MAX(maxfd, sd);
+      free(sin);
       CheckConnection(con);
       return;
    }
 
+#ifdef DEBUG
    if(debug)
       err_msg("Connection_process: Processed localfd=%d, remotefd=%d", con->localfd, sd);
+#endif
 
+   free(sin);
    con->remotefd = sd;
    maxfd = MAX(maxfd, sd);
    con->status = ST_INPROGR;
@@ -230,20 +278,31 @@ void Connection_DH_init(Connection *con, int how) {
    if(how == AS_NORMAL) {
       con->status = ST_DHSEND1;
       FD_SET(con->localfd, &wrset);
+
+#ifdef DEBUG
       if(debug)
          err_msg("Connection_DH_init: Generated DH data for localfd=%d", con->localfd);
+#endif
+
    } else if(how == AS_CHAIN) {
       con->status = ST_DHSEND2;
       FD_SET(con->remotefd, &wrset);
+
+#ifdef DEBUG
       if(debug)
 	 err_msg("Connection_DH_init: Generated DH data for remotefd=%d", con->remotefd);
+#endif
+
    } else if(how == AS_ENDPOINT) {
       con->status = ST_DHSEND3;
       con->rpos = DH_DATA_LEN;
       arcfour_encrypt(&con->e, con->rbuf, con->rbuf, DH_DATA_LEN);
       FD_SET(con->localfd, &wrset);
+
+#ifdef DEBUG
       if(debug)
          err_msg("Connection_DH_init: Generated DH data as endpoint for localfd=%d", con->localfd);
+#endif
    }
 }
 
@@ -259,8 +318,12 @@ void Connection_DH_senddata(Connection *con, int to) {
          Writedata(con, TO_LOCAL);
          FD_CLR(con->remotefd, &rdset);	/* Was set by Writedata() */
          if(!con->rpos) {
+
+#ifdef DEBUG
             if(debug)
 	       err_msg("Connection_DH_senddata: Send out all server DH data as endpoint to %s=%d", name, fd);
+#endif
+
 	    con->status = ST_DHRECV3;
             FD_CLR(con->localfd, &wrset);
 	    FD_SET(con->localfd, &rdset);
@@ -276,13 +339,21 @@ void Connection_DH_senddata(Connection *con, int to) {
 
    switch(n) {
       case -1:
+
+#ifdef DEBUG
          if(debug)
             err_ret("Connection_DH_senddata: write error to %s=%d", name, fd);
+#endif
+
          Connection_del(con);
          break;
       case 0: 	/* Huh?, when does this happen? */
+
+#ifdef DEBUG
 	 if(debug)
 	    err_ret("Connection_DH_senddata: write to %s=%d returned zero", name, fd);
+#endif
+
 	 Connection_del(con);
 	 break;
       default:
@@ -297,11 +368,17 @@ void Connection_DH_senddata(Connection *con, int to) {
 	       FD_SET(con->remotefd, &rdset);
 	    }
 	    con->rpos = 0;
+
+#ifdef DEBUG
             if(debug)
                err_msg("Connection_DH_senddata: Send out all server DH data to %s=%d", name, fd);
+#endif
+
          } else {
+#ifdef DEBUG
             if(debug)
                err_msg("Connection_DH_senddata: Send out %d bytes of DH data to %s=%d", n - con->rpos, name, fd);
+#endif
 	    con->rpos += n;
          }
    }
@@ -320,8 +397,10 @@ void Connection_DH_readdata(Connection *con, int from) {
          Readdata(con, FROM_LOCAL, max);
 	 FD_CLR(con->remotefd, &wrset);	/* Set by Readdata() */
          if(con->lpos == DH_DATA_LEN) {
+#ifdef DEBUG
             if(debug)
 	       err_msg("Connection_DH_readdata: Read in all client DH data as endpoint from %s=%d", name, fd);
+#endif
 	    con->lpos = 0;
 	    Connection_DH_process(con, AS_ENDPOINT);
          }
@@ -336,20 +415,26 @@ void Connection_DH_readdata(Connection *con, int from) {
 
    switch(n) {
       case -1:
+#ifdef DEBUG
          if(debug)
             err_ret("Connection_DH_readdata: read error from %s=%d", name, fd);
+#endif
          Connection_del(con);
          break;
       case 0:
+#ifdef DEBUG
 	 if(debug)
 	    err_ret("Connection_DH_readdata: premature end of file from %s=%d", name, fd);
+#endif
          Connection_del(con);
          break;
       default:
 	 con->lpos += n;
          if(con->lpos == DH_DATA_LEN) {
+#ifdef DEBUG
 	    if(debug)
 	       err_msg("Connection_DH_readdata: Read in all client DH data from %s=%d", name, fd);
+#endif
 	    con->lpos = 0;
 	    if(from == FROM_LOCAL)
                Connection_DH_process(con, AS_NORMAL);
@@ -357,8 +442,10 @@ void Connection_DH_readdata(Connection *con, int from) {
 	       Connection_DH_process(con, AS_CHAIN);
             return;
          } else {
+#ifdef DEBUG
             if(debug)
 	       err_msg("Connection_DH_readdata: Read in %d bytes of DH data from %s=%d", n, name, fd);
+#endif
 	 }
    }
    return;
@@ -369,17 +456,24 @@ void Connection_DH_process(Connection *con, int how) {
 
    memset(key, 0, 65);
    if(ComputeDH(con->lbuf, con->dh, NULL, key) != 0) {
-      err_msg("Connection_DH_process: ComputeDH failed");
+
+#ifdef DEBUG
+      if(debug)
+         err_msg("Connection_DH_process: ComputeDH failed");
+#endif
+
       Connection_del(con);
       return;
    }
 
+#ifdef DEBUG
    if(debug) {
       char *tmp = base64_encode(key, 64);
       err_msg("Connection_DH_process: DH negotiation succesful");
       err_msg("Connection_DH_process: Agreed key = %s", tmp);
       free(tmp);
    }
+#endif
 
    free(con->dh);	/* Not needed anymore */
    con->dh = NULL;
@@ -419,9 +513,12 @@ void Connection_eof(Connection *con, int who) {
    
    if(who == EOF_LOCAL) {
       if(con->lpos) {	/* We have data left to write out */
+
+#ifdef DEBUG
          if(debug)
             err_msg("Connection_eof: EOF for localfd=%d, %d bytes left to write out, entering ST_FINISHL state",
 		     con->localfd, con->lpos);
+#endif
 
 	 if(shutdown(con->remotefd, SHUT_RD))	/* We dont want more data */
 	    err_ret("Connection_eof: Shutdown error for remotefd=%d", con->remotefd);
@@ -433,15 +530,20 @@ void Connection_eof(Connection *con, int who) {
          con->status = ST_FINISHL;
 	 return;
       }
+#ifdef DEBUG
       if(debug)
 	 err_msg("Connection_eof: EOF for localfd=%d, no more data to write out", con->localfd);
+#endif
 
       Connection_del(con);
    } else if(who == EOF_REMOT) {
       if(con->rpos) {   /* We have data left to write out */
+
+#ifdef DEBUG
          if(debug)
 	    err_msg("Connection_eof: EOF for remotefd=%d, %d bytes left to write out, entering ST_FINISHR state", 
 	    con->remotefd, con->rpos);
+#endif
 
          if(shutdown(con->localfd, SHUT_RD))   /* We dont want more data */
             err_ret("Connection_eof: Shutdown error for localfd=%d", con->localfd);
@@ -453,8 +555,10 @@ void Connection_eof(Connection *con, int who) {
          con->status = ST_FINISHR;
 	 return;
       }
+#ifdef DEBUG
       if(debug)
          err_msg("Connection_eof: EOF for remotefd=%d, no more data to write out", con->remotefd);
+#endif
 
       Connection_del(con);
    }
