@@ -33,13 +33,14 @@
 #define CNTRL_CHAIN	2	/* Part of chain			*/
 #define CNTRL_ENDPO	4	/* Endpoint				*/
 #define CNTRL_DEBUG	8	/* Debug mode (undefined as of now)	*/
+#define CNTRL_INET6	16	/* IPv6 Address				*/
 
 #ifndef __GNUC__
  #pragma pack(1)
 #endif
 typedef struct _conninit {
    uint32_t     magic;          /* Magic Number: "AESO" in network order */
-   uint32_t     targetip;       /* Network Order */
+   uint8_t      targetip[16];   /* Network Order */
    uint16_t     targetport;     /* Network Order */
    uint16_t     control;        /* Control codes for proxy in network order */
 #ifndef __GNUC__
