@@ -1,4 +1,4 @@
-#include "general.h"
+#include "aesopd.h"
 
 Connection *conn = NULL;		/* Pointer to array of Connection structures 	*/
 int conn_size = 0;			/* Number of Connection structures in array  	*/
@@ -10,3 +10,9 @@ int debug = 0;				/* Interactive/debug mode			*/
 int sndbufsz = 0;			/* Size of TCP Sendbuffer			*/
 int timeout  = TIMEOUT;			/* Timeout					*/
 R_RSA_PRIVATE_KEY ServerPrivateKey;	/* Global Private RSA key of the server		*/
+
+#ifdef IPV6
+int ipv6support = 1;
+#else
+int ipv6support = 0;
+#endif
