@@ -1,13 +1,11 @@
-#include "general.h"
+#include "aesopd.h"
 
 void initialise(int argc, char **argv, int fd[2]) {
    char *chrootdir = NULL;
    char *keyfile = NULL;
    char *ptr;
-   struct sockaddr_in servaddr;
    int uid = -1, gid = -1;
-   int o, udp_probe = 1, opt = 1;
-   int listenhost, listenport;
+   int o, udp_probe = 1;
    long flags;
 
    opterr = 0;
@@ -21,8 +19,13 @@ void initialise(int argc, char **argv, int fd[2]) {
 	    version();
 	    break;
 	 case 'd':
+#ifndef DEBUG
+	    fprintf(stderr, "This aesop binary has not been built with debugging support\n");
+	    exit(-1);
+#else
 	    debug++;
 	    break;
+#endif
 	 case 'e':
 	    udp_probe = 0;
 	    break;
@@ -64,11 +67,24 @@ void initialise(int argc, char **argv, int fd[2]) {
    if(keyfile)
       free(keyfile);
 
-   if((fd[0] = socket(AF_INET, SOCK_STREAM, 0)) == -1)
-      err_sys("initialise: Can not SOCK_STREAM create socket");
+   fd[1] = 0;
 
-   if(setsockopt(fd[0], SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int)) == -1)
-      err_sys("initialise: Can not set SO_REUSEADDR");
+   if((argc - optind) > 0) {
+      if((ptr = strchr(argv[optind], '#'))) {
+         *ptr++ = '\0';
+	 fd[0] = w_listen(argv[optind], ptr, SOCK_STREAM);
+	 if(udp_probe)
+            fd[1] = w_listen(argv[optind], ptr, SOCK_DGRAM);
+      } else {
+	 fd[0] = w_listen(NULL, argv[optind], SOCK_STREAM);
+         if(udp_probe)
+	    fd[1] = w_listen(NULL, argv[optind], SOCK_DGRAM);
+      }
+   } else { 
+       fd[0] = w_listen(NULL, LISTEN_PORT_STRING, SOCK_STREAM);
+       if(udp_probe)
+          fd[1] = w_listen(NULL, LISTEN_PORT_STRING, SOCK_DGRAM);
+   }
 
    if((flags = fcntl(fd[0], F_GETFL, 0)) == -1)
       err_sys("initialise: fcntl F_GETFL error");
@@ -76,47 +92,6 @@ void initialise(int argc, char **argv, int fd[2]) {
    if(fcntl(fd[0], F_SETFL, flags | O_NONBLOCK) == -1)
       err_sys("initialise: fcntl F_SETFL error");
 
-   if((argc - optind) > 0) {
-      if((ptr = strchr(argv[optind], ':'))) {
-         struct hostent *host;
-
-         *ptr++ = '\0';
-         listenport = atoi(ptr);
-
-         if((host = gethostbyname(argv[optind])) == NULL) {
-            fprintf(stderr, "Error resolving %s: %s\n", argv[optind], hstrerror(h_errno));
-            exit(-1);
-         }
-         listenhost = *(int *)host->h_addr_list[0];
-      } else {
-	 listenport = atoi(argv[optind]);
-         listenhost = INADDR_ANY;
-      }
-   } else {
-      listenport = LISTEN_PORT;
-      listenhost = INADDR_ANY;
-   }
-
-   bzero(&servaddr, sizeof(servaddr));
-   servaddr.sin_family = AF_INET;
-   servaddr.sin_addr.s_addr = listenhost;
-   servaddr.sin_port = htons(listenport);
-
-   if(bind(fd[0], (struct sockaddr *)&servaddr, sizeof(servaddr)) == -1)
-      err_sys("initialise: Can not bind SOCK_STREAM socket");
-
-   if(listen(fd[0], SOMAXCONN) == -1)
-      err_sys("initialise: Can not listen");
-
-   if(udp_probe) {
-      if((fd[1] = socket(AF_INET, SOCK_DGRAM, 0)) == -1)
-         err_sys("initialise: Can not create SOCK_DGRAM socket");
-      if(bind(fd[1], (struct sockaddr *)&servaddr, sizeof(servaddr)) == -1)
-         err_sys("initialise: Can not bind SOCK_DGRAM socket");
-   } else {
-      fd[1] = 0;
-   }
-
    if(!sndbufsz) {
       socklen_t optlen = sizeof(int);
 
@@ -157,10 +132,12 @@ void initialise(int argc, char **argv, int fd[2]) {
 
 void usage(char *name) {
    fprintf(stderr, "aesopd: Advanced Encrypted Stackable Open Proxy v0.1\n");
-   fprintf(stderr, "usage: %s [options] [[listenhost:]port]\n", name);
+   fprintf(stderr, "usage: %s [options] [[listenhost[/v4|/v6]#]port]\n", name);
    fprintf(stderr, "where options are:\n");
    fprintf(stderr, "\t-h\t\t: Show this help\n");
+#ifdef DEBUG
    fprintf(stderr, "\t-d\t\t: Run the daemon in debug mode\n");
+#endif
    fprintf(stderr, "\t-c dir\t\t: Chroot daemon to dir\n");
    fprintf(stderr, "\t-u uid\t\t: Run daemon under uid\n");
    fprintf(stderr, "\t-g gid\t\t: Run daemon under gid\n");
@@ -175,6 +152,14 @@ void usage(char *name) {
 
 void version(void) {
    fprintf(stderr, "\tThis is aesop v%s\n", VERSION);
+   fprintf(stderr, "Built with:"
+#ifdef IPV6
+   " -DIPV6"
+#endif
+#ifdef DEBUG
+   " -DDEBUG"
+#endif
+   "\n");
    fprintf(stderr, "webpage: http://www.kryptology.org/aesop/\n");
    fprintf(stderr, "author:  bighawk, bighawk@kryptology.org\n");
    exit(0);
