@@ -1,4 +1,4 @@
-#include "general.h"
+#include "aesopd.h"
 
 void Readdata(Connection *con, int from, int max) {
    int n;
@@ -13,8 +13,12 @@ void Readdata(Connection *con, int from, int max) {
       if(max)
          free = MIN(free, max);
       if(sockatmark(con->localfd)) {
+
+#ifdef DEBUG
 	 if(debug)
 	    err_msg("Readdata: Read OOB data from localfd=%d", con->localfd);
+#endif
+
 	 oob_add(&con->l_oobpos, &con->l_oobsize, &con->l_oobused, con->lpos);
       }
       n = read(con->localfd, (con->lbuf + con->lpos), free);
@@ -26,8 +30,12 @@ void Readdata(Connection *con, int from, int max) {
       if(max)
          free = MIN(free, max);
       if(sockatmark(con->remotefd)) {
+
+#ifdef DEBUG
 	 if(debug)
 	    err_msg("Readdata: Read OOB data from remotefd=%d", con->remotefd);
+#endif
+
 	 oob_add(&con->r_oobpos, &con->r_oobsize, &con->r_oobused, con->rpos);
       }
       n = read(con->remotefd, (con->rbuf + con->rpos), free);
@@ -35,16 +43,24 @@ void Readdata(Connection *con, int from, int max) {
 
    switch(n) {
       case -1:
+
+#ifdef DEBUG
 	if(debug)
 	   err_ret("Readdata: Read error from %s=%d", name, fd);
+#endif
+
         Connection_del(con);
         break;
       case 0: 	/* eof */
 	Connection_eof(con, from == FROM_LOCAL ? EOF_LOCAL : EOF_REMOT);
 	break;
       default:
+
+#ifdef DEBUG
 	if(debug)
 	   err_msg("Readdata: Read %d bytes from %s=%d", n, name, fd);
+#endif
+
 	if(from == FROM_LOCAL) {
 	   arcfour_decrypt(&con->d, (con->lbuf + con->lpos), (con->lbuf + con->lpos), n); 
 	   if(con->init.control & CNTRL_CHAIN)
@@ -53,8 +69,12 @@ void Readdata(Connection *con, int from, int max) {
 	      arcfour_decrypt(&con->d2, (con->lbuf + con->lpos), (con->lbuf + con->lpos), n);
 	   con->lpos += n;
 	   if(con->lpos == sndbufsz) { /* Receive buffer is full, clear localfd from readset */
+
+#ifdef DEBUG
 	      if(debug)
 		 err_msg("Readdata: Receive buffer for localfd=%d is full", con->localfd);
+#endif
+
               FD_CLR(con->localfd, &rdset);
 	   }
 	   FD_SET(con->remotefd, &wrset); /* There's data to write */
@@ -66,8 +86,12 @@ void Readdata(Connection *con, int from, int max) {
 	   arcfour_encrypt(&con->e, (con->rbuf + con->rpos), (con->rbuf + con->rpos), n);
 	   con->rpos += n;
 	   if(con->rpos == sndbufsz) {	/* Receive buffer is full, clear remotefd from readset */
+
+#ifdef DEBUG
               if(debug)
                  err_msg("Readdata: Receive buffer for remotefd=%d is full", con->remotefd);
+#endif
+
               FD_CLR(con->remotefd, &rdset);
 	   }
 	   FD_SET(con->localfd, &wrset); /* There's data to write */
@@ -85,8 +109,12 @@ void Writedata(Connection *con, int to) {
       fd = con->localfd;
       name = "localfd";
       if(con->r_oobused && (con->r_oobpos[0] == 0)) {
+
+#ifdef DEBUG
 	 if(debug)
 	    err_msg("Writedata: Send 1 byte of OOB data to localfd=%d", con->localfd);
+#endif
+
          n = send(con->localfd, con->rbuf, 1, MSG_OOB);	/* We send 1 byte of OOB data	*/
 	 oob_shift(con->r_oobpos, &con->r_oobused);
       }
@@ -96,8 +124,12 @@ void Writedata(Connection *con, int to) {
       fd = con->remotefd;
       name = "remotefd";
       if(con->l_oobused && (con->l_oobpos[0] == 0)) {
+
+#ifdef DEBUG
 	 if(debug)
 	    err_msg("Writedata: Send 1 byte of OOB data to remotefd=%d", con->remotefd);
+#endif
+
 	 n = send(con->remotefd, con->lbuf, 1, MSG_OOB); /* We send 1 byte of OOB data	*/
 	 oob_shift(con->l_oobpos, &con->l_oobused);
       }
@@ -107,17 +139,28 @@ void Writedata(Connection *con, int to) {
 
    switch(n) {
       case -1:
+
+#ifdef DEBUG
         if(debug)
            err_ret("Writedata: Write error to %s=%d", name, fd);
+#endif
+
         Connection_del(con);
         break;	
       case 0:	/* Nothing written? strange.. */
+#ifdef DEBUG
 	if(debug)
 	   err_msg("Writedata: Write to %s=%d returned zero..", name, fd);
+#endif
+
 	 break;
       default:
+
+#ifdef DEBUG
 	if(debug)
            err_msg("Writedata: Wrote %d bytes to %s=%d", n, name, fd);
+#endif
+
 	if(to == TO_LOCAL) {
 	   con->rpos -= n;
 	   if(con->r_oobused)
@@ -155,14 +198,20 @@ void CheckConnection(Connection *con) {
       err_sys("main: getsockopt SO_ERROR error");
 
    if(error) {   /* connection did not succeed */
+
+#ifdef DEBUG
       if(debug)
          err_msg("main: Connection for remotefd=%d did not succeed", con->remotefd);
+#endif
+
       Connection_del(con);
       return;
    }
 
+#ifdef DEBUG
    if(debug)
       err_msg("main: Connection for remotefd=%d did succeed", con->remotefd);
+#endif
 
    FD_CLR(con->remotefd, &wrset);
 
