@@ -1,9 +1,11 @@
-#include "general.h"
+#include "aesoptunnel.h"
 
 void Connection_alloc(void) {
 
+#ifdef DEBUG
    if(debug)
       err_msg("Connection_alloc: allocating new structure, conn_size=%d", conn_size);
+#endif
 
    conn = realloc(conn, (conn_size + 1) * sizeof(Connection));
 
@@ -25,8 +27,10 @@ void Connection_alloc(void) {
 int Connection_add(int localfd) {
    int i;
 
+#ifdef DEBUG
    if(debug)
       err_msg("Connection_add: Adding Connection structure for fd=%d", localfd);
+#endif
 
    if(conn == NULL)
       Connection_alloc();
@@ -58,8 +62,10 @@ again:
 
 void Connection_del(Connection *con) {
 
+#ifdef DEBUG
    if(debug)
       err_msg("Connection_del: Deleting Connection structure for localfd=%d, remotefd=%d", con->localfd, con->remotefd);
+#endif
 
    if(con->localfd) {
       close(con->localfd);
@@ -92,12 +98,11 @@ void Connection_del(Connection *con) {
 }
 
 void Connection_connect(Connection *con) {
-   struct sockaddr_in sin;
    int sd, n;
    int val = 1;
    long flags;
 
-   if((sd = socket(AF_INET, SOCK_STREAM, 0)) == -1)
+   if((sd = socket(proxyhost->sa_family, SOCK_STREAM, 0)) == -1)
       err_sys("Connection_process: socket error");
 
    if((flags = fcntl(sd, F_GETFL, 0)) == -1)
@@ -109,12 +114,7 @@ void Connection_connect(Connection *con) {
    if(setsockopt(sd, SOL_SOCKET, SO_OOBINLINE, &val, sizeof(int)) == -1)
       err_sys("Connection_add: Can not set SO_OOBINLINE\n");
 
-   bzero(&sin, sizeof(sin));
-   sin.sin_family = AF_INET;
-   sin.sin_addr = proxyhost;
-   sin.sin_port = proxyport;
-
-   if((n = connect(sd, (struct sockaddr *)&sin, sizeof(sin))) == -1) {
+   if((n = connect(sd, proxyhost, proxyhostlen)) == -1) {
       if(errno != EINPROGRESS) {
          err_ret("Connection_process: connect didnt return EINPROGRESS");
          Connection_del(con);
@@ -127,8 +127,10 @@ void Connection_connect(Connection *con) {
       return;
    }
 
+#ifdef DEBUG
    if(debug)
       err_msg("Connection_process: Processed localfd=%d, remotefd=%d", con->localfd, sd);
+#endif
 
    con->remotefd = sd;
    maxfd = MAX(maxfd, sd);
@@ -153,15 +155,19 @@ void Connection_DH_init(Connection *con, int with) {
       con->status = ST_DHSEND1;
       con->rpos = 0;
       FD_SET(con->remotefd, &wrset);
+#ifdef DEBUG
       if(debug)
          err_msg("Connection_DH_init: Generated DH data for remotefd=%d", con->remotefd);
+#endif
    } else if(with == FOR_ENDPOINT) {
       con->status = ST_DHSEND2;
       con->rpos = 0;
       FD_SET(con->remotefd, &wrset);
       arcfour_encrypt(&con->e, con->rbuf, con->rbuf, DH_DATA_LEN);
+#ifdef DEBUG
       if(debug)
 	 err_msg("Connection_DH_init: Generated DH data for endpoint, remotefd=%d", con->remotefd);
+#endif
    }
 }
 
@@ -172,13 +178,17 @@ void Connection_DH_senddata(Connection *con) {
 
    switch(n) {
       case -1:
+#ifdef DEBUG
          if(debug)
             err_ret("Connection_DH_senddata: write error to remotefd=%d", con->remotefd);
+#endif
          Connection_del(con);
          break;
       case 0:   /* Huh?, when does this happen? */
+#ifdef DEBUG
          if(debug)
             err_ret("Connection_DH_senddata: write to remotefd=%d returned zero", con->remotefd);
+#endif
          Connection_del(con);
          break;
       default:
@@ -188,16 +198,22 @@ void Connection_DH_senddata(Connection *con) {
             FD_SET(con->remotefd, &rdset);
 	    if(con->status == ST_DHSEND1) {
                con->status = ST_DHRECV1;
+#ifdef DEBUG
                if(debug)
                   err_msg("Connection_DH_senddata: Send out all server DH data to remotefd=%d", con->remotefd);
+#endif
 	    } else {	/* ST_DHSEND2	*/
 	       con->status = ST_DHRECV2;
+#ifdef DEBUG
                if(debug)
                   err_msg("Connection_DH_senddata: Send out all server DH data to remotefd=%d for endpoint", con->remotefd);
+#endif
             }
          } else {
+#ifdef DEBUG
             if(debug)
                err_msg("Connection_DH_senddata: Send out %d bytes of DH data to remotefd=%d", n - con->rpos, con->remotefd);
+#endif
             con->rpos += n;
          }
    }
@@ -211,8 +227,10 @@ void Connection_DH_readdata(Connection *con) {
       Readdata(con, FROM_REMOTE, max);
       FD_CLR(con->localfd, &wrset); /* Set by Readdata() */
       if(con->rpos == DH_DATA_LEN) {
+#ifdef DEBUG
          if(debug)
             err_msg("Connection_DH_readdata: Read in all DH data from endpoint from remotefd=%d", con->remotefd);
+#endif
          con->rpos = 0;
          Connection_DH_process(con, FOR_ENDPOINT);
       }
@@ -223,26 +241,34 @@ void Connection_DH_readdata(Connection *con) {
 
    switch(n) {
       case -1:
+#ifdef DEBUG
          if(debug)
             err_ret("Connection_DH_readdata: read error from remotefd=%d", con->remotefd);
+#endif
          Connection_del(con);
          break;
       case 0:
+#ifdef DEBUG
          if(debug)
             err_ret("Connection_DH_readdata: premature end of file from remotefd=%d", con->remotefd);
+#endif
          Connection_del(con);
          break;
       default:
          con->rpos += n;
          if(con->rpos == DH_DATA_LEN) {
+#ifdef DEBUG
             if(debug)
                err_msg("Connection_DH_readdata: Read in all client DH data from remotefd=%d", con->remotefd);
+#endif
             con->rpos = 0;
             Connection_DH_process(con, FOR_NORMAL);
             return;
          } else {
+#ifdef DEBUG
             if(debug)
                err_msg("Connection_DH_readdata: Read in %d bytes of DH data from remotefd=%d", n, con->remotefd);
+#endif
          }
    }
    return;
@@ -260,17 +286,22 @@ void Connection_DH_process(Connection *con, int with) {
       con->dh->server = 0;
 
    if((num = ComputeDH(con->rbuf, con->dh, &ServerPublicKey, key)) != 0) {
-      err_msg("Connection_DH_process: ComputeDH failed: %d", num);
+#ifdef DEBUG
+      if(debug)
+         err_msg("Connection_DH_process: ComputeDH failed: %d", num);
+#endif
       Connection_del(con);
       return;
    }
 
+#ifdef DEBUG
    if(debug) {
       char *tmp = base64_encode(key, 64);
       err_msg("Connection_DH_process: DH negotiation succesful");
       err_msg("Connection_DH_process: Agreed key = %s", tmp);
       free(tmp);
    }
+#endif
 
    free(con->dh);      /* Not needed anymore */
    con->dh = NULL;
@@ -307,8 +338,10 @@ void Connection_sendinfo(Connection *con) {
    Writedata(con, TO_REMOTE);
 
    if(!con->lpos) {	/* Wrote out all control data	*/
+#ifdef DEBUG
       if(debug)
 	 err_msg("Connection_sendinfo: Wrote out all control headers to remotefd=%d", con->remotefd);
+#endif
       if(cntrl_num > 1) {	/* Talking with chain of proxies, have to do dh with endpoint	*/
 	 FD_CLR(con->localfd, &rdset);	/* Set by Writedata()   */
 	 Connection_DH_init(con, FOR_ENDPOINT);
@@ -327,29 +360,36 @@ void Connection_eof(Connection *con, int who) {
 
    if(who == EOF_LOCAL) {
       if(con->lpos) {  /* We have data left to write out */
+#ifdef DEBUG
          if(debug)
             err_msg("Connection_eof: EOF for localfd=%d, %d bytes left to write out, entering ST_FINISHL state",
           con->localfd, con->lpos);
+#endif
 
-    if(shutdown(con->remotefd, SHUT_RD))     /* We dont want more data */
-       err_ret("Connection_eof: Shutdown error for remotefd=%d", con->remotefd);
+          if(shutdown(con->remotefd, SHUT_RD))     /* We dont want more data */
+             err_ret("Connection_eof: Shutdown error for remotefd=%d", con->remotefd);
 
-    FD_CLR(con->localfd, &rdset);
-    FD_CLR(con->localfd, &wrset);
-    FD_CLR(con->remotefd, &rdset);
-    FD_SET(con->remotefd, &wrset);
-         con->status = ST_FINISHL;
-    return;
+          FD_CLR(con->localfd, &rdset);
+          FD_CLR(con->localfd, &wrset);
+          FD_CLR(con->remotefd, &rdset);
+          FD_SET(con->remotefd, &wrset);
+          con->status = ST_FINISHL;
+          return;
       }
+
+#ifdef DEBUG
       if(debug)
-    err_msg("Connection_eof: EOF for localfd=%d, no more data to write out", con->localfd);
+         err_msg("Connection_eof: EOF for localfd=%d, no more data to write out", con->localfd);
+#endif
 
       Connection_del(con);
    } else if(who == EOF_REMOT) {
       if(con->rpos) {   /* We have data left to write out */
+#ifdef DEBUG
          if(debug)
-       err_msg("Connection_eof: EOF for remotefd=%d, %d bytes left to write out, entering ST_FINISHR state",
-       con->remotefd, con->rpos);
+            err_msg("Connection_eof: EOF for remotefd=%d, %d bytes left to write out, entering ST_FINISHR state",
+               con->remotefd, con->rpos);
+#endif
 
          if(shutdown(con->localfd, SHUT_RD))   /* We dont want more data */
             err_ret("Connection_eof: Shutdown error for localfd=%d", con->localfd);
@@ -359,10 +399,12 @@ void Connection_eof(Connection *con, int who) {
          FD_CLR(con->localfd, &rdset);
          FD_SET(con->localfd, &wrset);
          con->status = ST_FINISHR;
-    return;
+         return;
       }
+#ifdef DEBUG
       if(debug)
          err_msg("Connection_eof: EOF for remotefd=%d, no more data to write out", con->remotefd);
+#endif
 
       Connection_del(con);
    }
