@@ -1,4 +1,4 @@
-#include "general.h"
+#include "aesoptunnel.h"
 
 Connection *conn = NULL;                /* Pointer to array of Connection structures    */
 int conn_size = 0;                      /* Number of Connection structures in array     */
@@ -12,6 +12,11 @@ R_RSA_PUBLIC_KEY ServerPublicKey;	/* Public RSA key of the proxy			*/
 int probe_all = 0;			/* Do an UDP probe on all proxies		*/
 int skip_ok = 0;			/* May skip proxies in a chain if they are not up	*/
 int skip_verification = 0;		/* Set true if the Server signature does nto have to be verified	*/
-int h_errno;				/* For hstrerror()				*/
-struct in_addr proxyhost = { 0 };	/* First proxy this tunnel is connecting with	*/
-short proxyport = 0;			/* Remote port of proxy in network order	*/		
+int h_errno;				/* Resolver error var.				*/
+struct sockaddr *proxyhost = NULL;	/* First proxy, used for a direct connection.	*/
+socklen_t proxyhostlen = 0;		/* Size of proxyhost				*/
+#ifdef IPV6				/* Runtime ipv6 support checking		*/
+int ipv6support = 1;
+#else
+int ipv6support = 0;
+#endif
