@@ -1,12 +1,10 @@
-#include "general.h"
+#include "aesoptunnel.h"
 
 int initialise(int argc, char **argv) {
-   struct sockaddr_in servaddr;
    char *file = NULL, *label = NULL;
    char *keyfile = NULL;
    char *ptr;
-   int listenport, listenhost;
-   int o, sd, opt = 1;
+   int o, sd;
    long flags;
 
    opterr = 0;
@@ -20,7 +18,12 @@ int initialise(int argc, char **argv) {
 	   version();
 	   break;
 	case 'd':
+#ifndef DEBUG
+	   fprintf(stderr, "This aesoptunnel binary has not been built with debugging support\n");
+	   exit(-1);
+#else
 	   debug++;
+#endif
 	   break;
 	case 'u':
 	   probe_all = 1;
@@ -67,11 +70,11 @@ int initialise(int argc, char **argv) {
    if(LoadPublicKey(keyfile ? keyfile : PUBLIC_KEY_FILE, &ServerPublicKey) != 0)
       exit(-1);         /* LoadPrivateKey prints error message */
 
-   if((sd = socket(AF_INET, SOCK_STREAM, 0)) == -1)
-      err_sys("initialise: Can not SOCK_STREAM create socket");
-
-   if(setsockopt(sd, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int)) == -1)
-      err_sys("initialise: Can not set SO_REUSEADDR");
+   if((ptr = strchr(argv[optind+1], '#'))) {
+      *ptr++ = '\0';
+      sd = w_listen(argv[optind+1], ptr, SOCK_STREAM);
+   } else
+      sd = w_listen(NULL, argv[optind+1], SOCK_STREAM);
 
    if((flags = fcntl(sd, F_GETFL, 0)) == -1)
       err_sys("initialise: fcntl F_GETFL error");
@@ -79,33 +82,6 @@ int initialise(int argc, char **argv) {
    if(fcntl(sd, F_SETFL, flags | O_NONBLOCK) == -1)
       err_sys("initialise: fcntl F_SETFL error");
 
-   if((ptr = strchr(argv[optind+1], ':'))) {
-      struct hostent *host;
-
-      *ptr++ = '\0';
-      listenport = atoi(ptr);
-
-      if((host = gethostbyname(argv[optind+1])) == NULL) {
-         fprintf(stderr, "Error resolving %s: %s\n", argv[optind+1], hstrerror(h_errno));
-         exit(-1);
-      }
-      listenhost = *(int *)host->h_addr_list[0];
-   } else {
-      listenport = atoi(argv[optind+1]);
-      listenhost = INADDR_ANY;
-   }
-
-   bzero(&servaddr, sizeof(servaddr));
-   servaddr.sin_family = AF_INET;
-   servaddr.sin_addr.s_addr = listenhost;
-   servaddr.sin_port = htons(listenport);
-
-   if(bind(sd, (struct sockaddr *)&servaddr, sizeof(servaddr)) == -1)
-      err_sys("initialise: Can not bind SOCK_STREAM socket");
-
-   if(listen(sd, SOMAXCONN) == -1)
-      err_sys("initialise: Can not listen");
-
    if(!sndbufsz) {
       socklen_t optlen = sizeof(int);
 
@@ -118,7 +94,7 @@ int initialise(int argc, char **argv) {
 
    parse_file(file, label);
 
-   if((ptr = strchr(argv[optind], ':'))) {
+   if((ptr = strchr(argv[optind], '#'))) {
       *ptr++ = '\0';
 
       add_proxy(argv[optind], atoi(ptr), 0);
@@ -127,6 +103,16 @@ int initialise(int argc, char **argv) {
 
    proxy_final();
 
+#ifdef IPV6
+   {	/* Check if an actual IPv6 stack is present.	*/
+      int sd2;
+      if(((sd2 = socket(AF_INET6, SOCK_STREAM, 0)) == -1) && proxyhostlen == sizeof(struct sockaddr_in6))
+         err_quit("Error: Aesop has been built with IPv6 support, but there is no IPv6 stack available\n"
+                  "       and the first proxy specified is an IPv6 host: aborting\n");
+      close(sd2);
+   }
+#endif
+
    if(!debug) {
       if(fork()) {
          exit(0);
@@ -145,10 +131,12 @@ int initialise(int argc, char **argv) {
 
 void usage(char *name) {
    fprintf(stderr, "aesoptunnel: Client Tunnel for Aesop \n");
-   fprintf(stderr, "usage: %s [options] [destinationhost:]port [listenhost:]port\n", name);
+   fprintf(stderr, "usage: %s [options] [destinationhost[/v4|/v6]#]port [listenhost[/v4|/v6]#]port\n", name);
    fprintf(stderr, "where options are:\n");
    fprintf(stderr, "\t-h\t\t: Show this help\n");
+#ifdef DEBUG
    fprintf(stderr, "\t-d\t\t: Run the tunnel in debug mode\n");
+#endif
    fprintf(stderr, "\t-f file\t\t: Specify file to load routes from\n");
    fprintf(stderr, "\t-l label\t: Specify the label for the chain, default: first label\n");
    fprintf(stderr, "\t-k file\t\t: Specify the public key file of the proxy\n");
@@ -161,6 +149,14 @@ void usage(char *name) {
 
 void version(void) {
    fprintf(stderr, "\tThis is aesoptunnel v%s\n", VERSION);
+   fprintf(stderr, "Built with:"
+#ifdef IPV6
+   " -DIPV6"
+#endif
+#ifdef DEBUG
+   " -DDEBUG"
+#endif
+   "\n");
    fprintf(stderr, "webpage: http://www.kryptology.org/aesop/\n");
    fprintf(stderr, "author:  bighawk, bighawk@kryptology.org\n");
    exit(0);
