@@ -1,19 +1,27 @@
-#include "general.h"
+#include "aesoptunnel.h"
 
-int probe_proxy(char *ip, int port) {
+int probe_proxy(char *ip, int port, int inet6) {
    int num_probes = 3;
    int sd, result = 1;
-   struct sockaddr_in sin;
+   struct sockaddr *sa;
+   socklen_t sinlen;
 
-   bzero(&sin, sizeof(sin));
-   sin.sin_family = AF_INET;
-   sin.sin_port = htons(port);
-   memcpy(&sin.sin_addr.s_addr, ip, 4);
+   if(!ipv6support && inet6) {
+      err_msg("probe_proxy: Warning, host not built with IPv6 support, skipping host");
+      return 0;
+   }      
 
-   if((sd = socket(AF_INET, SOCK_DGRAM, 0)) == -1)
-      err_sys("Can not create SOCK_DGRAM socket");
+   sa = w_setsockaddr(ip, port, &sinlen, inet6);
 
-   if(connect(sd, (struct sockaddr *)&sin, sizeof(sin)) == -1)
+   if((sd = socket(sa->sa_family, SOCK_DGRAM, 0)) == -1) {
+      if(errno == EAFNOSUPPORT) {
+         err_msg("probe_proxy: Warning, host built with IPv6 support, but without IPv6 stack, skipping host");
+         free(sa);
+      }
+      err_sys("probe_proxy: Can not create SOCK_DGRAM socket");
+   }
+
+   if(connect(sd, sa, sinlen) == -1)
       err_sys("Can not connect to dgram socket");
 
    while(num_probes--) {
@@ -43,5 +51,6 @@ int probe_proxy(char *ip, int port) {
    }
 
    close(sd);
+   free(sa);
    return result;
 }
