@@ -15,8 +15,8 @@ int main(int argc, char **argv) {
       fprintf(stderr, "usage: %s <publickeyfile> <privatekeyfile>\n", argv[0]), exit(-1);
 
    InitRandomStruct(&RandomStruct);
-   if(InitProtoKey(1024, 1, &ProtoKey))
-      exit(-1);
+   if((n = InitProtoKey(1024, 1, &ProtoKey)))
+      fprintf(stderr, "InitProtoKey returned %d\n", n), exit(-1);
    if((n = R_GeneratePEMKeys(&PublicKey, &PrivateKey, &ProtoKey, &RandomStruct)))
       fprintf(stderr, "R_GeneratePEMKeys returned %d\n", n), exit(-1);
 
