@@ -1,4 +1,4 @@
-#include "arcfour.h"
+#include "general.h"
 #include <assert.h>
 
 void arcfour_init(ArcfourContext *ctx, const unsigned char *key, 
@@ -31,7 +31,10 @@ void arcfour_init(ArcfourContext *ctx, const unsigned char *key,
     }
 }
 
-inline unsigned int arcfour_byte(ArcfourContext *ctx)
+#ifdef __GNUC__
+inline
+#endif
+unsigned int arcfour_byte(ArcfourContext *ctx)
 {
   unsigned int x;
   unsigned int y;
