@@ -1,14 +1,4 @@
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include "global.h"
-#include "rsaref.h"
-#include "base64.h"
-#include "crypto.h"
+#include "general.h"
 
 unsigned int urand(void)
 {
@@ -159,7 +149,7 @@ int LoadPrivateKey(char *file, R_RSA_PRIVATE_KEY *privateKey) {
    return 0;
 }
 
-int StorePart(FILE *fptr, char *src, int size) {
+int StorePart(FILE *fptr, void *src, int size) {
    char *ptr;
 
    ptr = base64_encode(src, size);
@@ -169,7 +159,7 @@ int StorePart(FILE *fptr, char *src, int size) {
    return 0;
 }
 
-int LoadPart(FILE *fptr, char *dest, int size) {
+int LoadPart(FILE *fptr, void *dest, int size) {
    char tempbuf[2000]; /* adjust this */
    char *ptr;
    int len;
