@@ -1,16 +1,11 @@
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include "error.h"
-#include "oob_queue.h"
+#include "general.h"
 
-extern int debug;
 
 /* Add an OOB position to the *_oobpos array	*/
 void oob_add(int **posarray, int *size, int *used, int pos) {
    
    if(*size == *used) {
-      if(((void *)*posarray = realloc((void *)*posarray, *size + 1)) == NULL)
+      if((*posarray = realloc(*posarray, *size + 1)) == NULL)
 	 err_sys("add_oob: Memory allocation error");
      
       *size += 1;
