@@ -1,6 +1,4 @@
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/ioctl.h>
+#include "general.h"
 
 int sockatmark(int fd) {
    int flag;
